ad_library {

    An API for managing documents.

    @creation-date 22 May 2000
    @author Jon Salz [jsalz@arsdigita.com]
    @cvs-id $Id: document-init.tcl,v 1.2.2.1 2015/09/10 08:21:56 gustafn Exp $

}

ns_adp_registerscript ad-document "/ad-document" doc_tag_ad_document
ns_adp_registerscript ad-property "/ad-property" doc_tag_ad_property

# Local variables:
#    mode: tcl
#    tcl-indent-level: 4
#    indent-tabs-mode: nil
# End:
